@@ -69,11 +69,11 @@ sub _options {
             { name => '_db_defaults', text => '', section => ''  },
         ],
         group_extensions => [
-            { name => '_e_table',        text => "- Tables menu",  section => 'enable' },
-            { name => '_e_join',         text => "- Join menu",    section => 'enable' },
-            { name => '_e_union',        text => "- Union menu",   section => 'enable' },
-            { name => '_e_columns',      text => "- Column menus", section => 'enable' },
-            { name => '_e_write_access', text => "- Write access", section => 'enable' },
+            { name => '_e_table',        text => "- Tables menu",        section => 'enable' },
+            { name => '_e_join',         text => "- Join menu",          section => 'enable' },
+            { name => '_e_union',        text => "- Union menu",         section => 'enable' },
+            { name => '_e_expressions',  text => "- Columns and Values", section => 'enable' },
+            { name => '_e_write_access', text => "- Write access",       section => 'enable' },
         ],
         group_sql_settings => [
             { name => '_meta',                   text => "- System DB/Tables", section => 'G'      },
@@ -298,11 +298,11 @@ sub set_options {
                 ];
                 $sf->__settings_menu_wrap( $section, $sub_menu, $prompt );
             }
-            elsif ( $opt eq '_e_columns' ) {
-                my $prompt = 'Column menus:';
+            elsif ( $opt eq '_e_expressions' ) {
+                my $prompt = 'Extended expressions:';
                 my $sub_menu = [
-                    [ 'col_menu_addition', "- Column menu additions", [ $no, $yes ] ],
-                    [ 'parentheses',       "- Add Parentheses",       [ $no, $yes ] ],
+                    [ 'extended_cols',   "- Exdented Columns", [ $no, $yes ] ],
+                    [ 'extended_values', "- Exdented Values",  [ $no, $yes ] ],
                 ];
                 $sf->__settings_menu_wrap( $section, $sub_menu, $prompt );
             }
